@@ -7,13 +7,12 @@ import numpy as np
 import xgboost as xgb
 from boruta import BorutaPy
 from tsfresh.utilities.dataframe_functions import impute
-from tsfresh.feature_extraction import ComprehensiveFCParameters
+from tsfresh.feature_extraction import ComprehensiveFCParameters, settings, extract_features
 from tsfresh import extract_features, extract_relevant_features, select_features
 
 
 
 
-
 FEATURES = [ 'exp_unique_id', 'timesteps', 'sensor_1', 'sensor_2',
        'sensor_3', 'sensor_4', 'sensor_5', 'sensor_6', 'sensor_7', 'sensor_8',
        'sensor_9', 'sensor_10', 'sensor_11', 'sensor_12', 'sensor_13',
@@ -28,7 +27,7 @@ extraction_settings = ComprehensiveFCParameters()
 def get_features(df, unique_id='exp_unique_id', label='result', timesteps='timesteps', features=FEATURES):
 
 
-    df = df[FEATURES]
+    df = df[features]
 
     X = df.drop(label, axis=1)
     y = df.groupby(unique_id).first()[label]
@@ -49,7 +48,7 @@ def get_relevant_features(X, y, tree_model=xgb):
 
 
     boruta = BorutaPy(
-    estimator = xgb, 
+    estimator = tree_model, 
     n_estimators = 'auto',
     max_iter = 100 # number of trials to perform
     )
@@ -67,7 +66,23 @@ def get_relevant_features(X, y, tree_model=xgb):
     df_X = X[relevant_features]
     df = df_X.join(y)
 
-    # remove unwanted characters from the column names
-    df.columns = df.columns.str.replace('[",\d, (, )]', '')
 
-    return df, relevant_features
+
+    return df
+
+
+def get_prediction_features(df, relevant_features, id='exp_unique_id', timesteps='timesteps'):
+
+    fc_parameters = settings.from_columns(df.drop(relevant_features))
+
+    prediction_data = extract_features(df, kind_to_fc_parameters =fc_parameters, column_id=id, column_sort=timesteps)
+
+    return prediction_data
+
+
+
+
+
+
+
+
